@@ -1,7 +1,8 @@
 /// Creates a new [`StaticVec`](crate::StaticVec) from a [`vec!`](alloc::vec::Vec)-style
 /// pseudo-slice. The newly created [`StaticVec`](crate::StaticVec) will have a capacity and length
 /// exactly equal to the number of elements in the so-called slice. The "array-like" `[value; N]`
-/// syntax is also supported, and both forms can be used in const contexts.
+/// syntax is also supported, and both forms can be used in const contexts. This macro has no
+/// particular trait impl requirements for the input type.
 ///
 /// Example usage:
 /// ```
@@ -16,7 +17,7 @@
 /// const V3: StaticVec<i32, 4> = staticvec![1, 2, 3, 4];
 /// assert_eq!(V3, [1, 2, 3, 4]);
 ///
-/// const V4: StaticVec<i32, 128> = staticvec![27; 128];
+/// static V4: StaticVec<i32, 128> = staticvec![27; 128];
 /// assert!(V4 == [27; 128]);
 /// ```
 #[macro_export]
@@ -29,9 +30,88 @@ macro_rules! staticvec {
   };
 }
 
-// This is the same macro available in my actual `staticsort` crate, which I previously had as
-// a dependency for this crate but decided to "inline" here as considering I wrote it myself it
-// seems silly to have a mandatory dependency for no real reason.
+/// This is only used in the `staticstring!` macro at the moment.
+#[doc(hidden)]
+#[macro_export]
+macro_rules! __static_assert {
+  ($b:expr) => {{
+    const VERIFIER: [(); 1] = [()];
+    const _: () = VERIFIER[!($b) as usize];
+  };};
+}
+
+/// Creates a new [`StaticString`] from an `&str` literal. This macro can be used in const
+/// contexts, in keeping with the other ones in this crate.
+///
+/// The `staticstring!` macro comes in two forms: one that solely takes an `&str` literal,
+/// where the resulting [`StaticString`] will have a total capacity exactly equal to the
+/// number of bytes in the literal, and one that takes an additional integral constant
+/// which is then used to specify the capacity independently from the length of the input
+/// string.
+///
+/// Implemententing it as such allows the macro be more flexible than would otherwise
+/// be possible due to the required level of type inference being beyond what the compiler
+/// is (currently at least) capable of.
+///
+/// Example usage:
+/// ```
+/// use staticvec::{staticstring, StaticString};
+///
+/// // Usage at runtime, creating a `StaticString` with both a length and capacity of 10:
+/// let s1 = staticstring!("ABCDEFGHIJ");
+/// assert_eq!(s1, "ABCDEFGHIJ");
+///
+/// // Usage at runtime, creating a `StaticString` with a length of 10 but a capacity of 20:
+/// let s2 = staticstring!("ABCDEFGHIJ", 20);
+/// assert_eq!(s2, "ABCDEFGHIJ");
+///
+/// // Usage at compile time, creating a `StaticString` with both a length and capacity of 10:
+/// const S3: StaticString<10> = staticstring!("ABCDEFGHIJ");
+/// assert_eq!(S3, "ABCDEFGHIJ");
+///
+/// // Usage at compile time, creating a `StaticString` with a length of 18 but a capacity of 36,
+/// // keeping in mind that length is measured in bytes and not characters of course:
+/// const S4: StaticString<36> = staticstring!("BC🤔BC🤔BC🤔", 36);
+/// assert_eq!(S4, "BC🤔BC🤔BC🤔");
+/// ```
+///
+/// Note that attempting to explicitly provide a capacity that is less than the number of bytes
+/// in the input string will fail a *compile-time* static assertion in both const and runtime
+/// contexts.
+///
+/// For example, this would give a compile-time error:
+/// ```
+/// // const S5: StaticString<1> = staticstring!("ABCDEFG", 1);
+/// ```
+/// As would the following:
+/// ```
+/// // let s6 = staticstring!("🤔🤔🤔🤔🤔🤔", 0);
+/// ```
+#[macro_export]
+#[rustfmt::skip]
+macro_rules! staticstring {
+  ($val:expr) => {{
+    const CAP: usize = $val.len();
+    unsafe {
+      $crate::StaticString::<CAP>::__new_from_staticvec(
+        $crate::StaticVec::<u8, CAP>::__from_const_str($val)
+      )
+    }
+  };};
+  ($val:expr, $n:expr) => {{
+    const CAP: usize = $n;
+    $crate::__static_assert!($val.len() <= CAP);
+    unsafe {
+      $crate::StaticString::<CAP>::__new_from_staticvec(
+        $crate::StaticVec::<u8, CAP>::__from_const_str($val)
+      )
+    }
+  };};
+}
+
+/// This is the same macro available in my actual `staticsort` crate, which I previously had as
+/// a dependency for this crate but decided to "inline" here as considering I wrote it myself it
+/// seems silly to have a mandatory dependency for no real reason.
 #[doc(hidden)]
 #[macro_export]
 macro_rules! __staticsort {
