@@ -432,8 +432,8 @@ impl<const N: usize> From<StaticString<N>> for StaticVec<u8, N> {
   }
 }
 
+/// **Note:** this is only available when the `std` crate feature is enabled.
 #[cfg(feature = "std")]
-#[doc(cfg(feature = "std"))]
 impl<T, const N: usize> From<Vec<T>> for StaticVec<T, N> {
   /// Functionally equivalent to [`from_vec`](crate::StaticVec::from_vec).
   #[inline(always)]
@@ -650,8 +650,8 @@ impl<T, const N: usize> IndexMut<RangeToInclusive<usize>> for StaticVec<T, N> {
   }
 }
 
+/// **Note:** this is only available when the `std` crate feature is enabled.
 #[cfg(feature = "std")]
-#[doc(cfg(feature = "std"))]
 impl<T, const N: usize> Into<Vec<T>> for StaticVec<T, N> {
   /// Functionally equivalent to [`into_vec`](crate::StaticVec::into_vec).
   #[inline(always)]
@@ -750,6 +750,8 @@ impl_partial_ord_with_as_slice_against_slice!(&mut [T1], StaticVec<T2, N>);
 
 /// Read from a StaticVec. This implementation operates by copying bytes into the destination
 /// buffers, then shifting the remaining bytes over.
+///
+/// **Note:** this is only available when the `std` crate feature is enabled.
 #[cfg(feature = "std")]
 impl<const N: usize> Read for StaticVec<u8, N> {
   #[inline(always)]
@@ -852,6 +854,7 @@ impl<const N: usize> Read for StaticVec<u8, N> {
   }
 }
 
+/// **Note:** this is only available when the `std` crate feature is enabled.
 #[cfg(feature = "std")]
 impl<const N: usize> Write for StaticVec<u8, N> {
   #[inline]
@@ -892,6 +895,7 @@ impl<const N: usize> Write for StaticVec<u8, N> {
   }
 }
 
+/// **Note:** this is only available when the `std` crate feature is enabled.
 #[cfg(feature = "std")]
 impl<const N: usize> BufRead for StaticVec<u8, N> {
   #[inline(always)]
